@@ -1,6 +1,6 @@
 from datetime import datetime
-from orionis.console.output.contracts.executor import IExecutor
-from orionis.console.output.enums.styles import ANSIColors
+from orionis.console.contracts.executor import IExecutor
+from orionis.console.enums.styles import ANSIColors
 
 class Executor(IExecutor):
 
