@@ -25,16 +25,16 @@ from orionis.console.contracts.reactor import IReactor
 from orionis.console.contracts.schedule import ISchedule
 from orionis.console.contracts.schedule_event_listener import IScheduleEventListener
 from orionis.console.entities.event_job import EventJob
-from orionis.console.entities.request import CLIRequest
 from orionis.console.entities.scheduler_error import SchedulerError
 from orionis.console.entities.scheduler_paused import SchedulerPaused
 from orionis.console.entities.scheduler_resumed import SchedulerResumed
 from orionis.console.entities.scheduler_shutdown import SchedulerShutdown
 from orionis.console.entities.scheduler_started import SchedulerStarted
-from orionis.console.enums.event import Event as EventEntity
+from orionis.console.entities.event import Event as EventEntity
 from orionis.console.enums.listener import ListeningEvent
 from orionis.console.exceptions import CLIOrionisRuntimeError
-from orionis.console.exceptions.cli_orionis_value_error import CLIOrionisValueError
+from orionis.console.exceptions import CLIOrionisValueError
+from orionis.console.request.cli_request import CLIRequest
 from orionis.failure.contracts.catch import ICatch
 from orionis.foundation.contracts.application import IApplication
 from orionis.services.log.contracts.log_service import ILogger
@@ -166,7 +166,7 @@ class Schedule(ISchedule):
             # Store each job's signature and description in the commands dictionary
             commands[job['signature']] = {
                 'signature': job['signature'],
-                'description': job.get('description', '')
+                'description': job.get('description', 'No description available.')
             }
 
         # Return the commands dictionary
@@ -267,7 +267,7 @@ class Schedule(ISchedule):
 
         # Prevent adding new commands while the scheduler is running
         if self.isRunning():
-            raise CLIOrionisRuntimeError("Cannot add new commands while the scheduler is running.")
+            self.__raiseException(CLIOrionisValueError("Cannot add new commands while the scheduler is running."))
 
         # Validate that the command signature is a non-empty string
         if not isinstance(signature, str) or not signature.strip():
@@ -282,7 +282,7 @@ class Schedule(ISchedule):
             raise CLIOrionisValueError(f"The command '{signature}' is not available or does not exist.")
 
         # Import Event here to avoid circular dependency issues
-        from orionis.console.tasks.event import Event
+        from orionis.console.fluent.event import Event
 
         # Store the command and its arguments for scheduling
         self.__events[signature] = Event(
@@ -464,7 +464,7 @@ class Schedule(ISchedule):
 
         # Validate that the provided event is an instance of ListeningEvent
         if not isinstance(listening_vent, ListeningEvent):
-            raise CLIOrionisValueError("The event must be an instance of ListeningEvent.")
+            self.__raiseException(CLIOrionisValueError("The event must be an instance of ListeningEvent."))
 
         # Retrieve the global identifier for the event from the ListeningEvent enum
         scheduler_event = listening_vent.value
@@ -478,49 +478,11 @@ class Schedule(ISchedule):
             # If is Callable
             if callable(listener):
 
+                # Invoke the listener, handling both coroutine and regular functions
                 try:
-
-                    # If the listener is a coroutine, handle it properly
-                    if asyncio.iscoroutinefunction(listener):
-
-                        try:
-
-                            # Try to get the current running event loop
-                            loop = asyncio.get_running_loop()
-
-                            # Schedule the coroutine as a task in the current loop
-                            loop.create_task(listener(event_data, self))
-
-                        except RuntimeError:
-
-                            # No running event loop, create a new one
-                            try:
-
-                                # Create and run the coroutine in a new event loop
-                                asyncio.run(listener(event_data, self))
-
-                            except Exception as e:
-
-                                # Handle exceptions during coroutine execution
-                                error_msg = f"Failed to run async listener for '{scheduler_event}': {str(e)}"
-                                self.__logger.error(error_msg)
-                                raise CLIOrionisRuntimeError(error_msg) from e
-
-                    else:
-
-                        # Call the regular listener function directly
-                        listener(event_data, self)
-
-                except Exception as e:
-
-                    # Re-raise CLIOrionisRuntimeError exceptions
-                    if isinstance(e, CLIOrionisRuntimeError):
-                        raise e
-
-                    # Construct and log error message
-                    error_msg = f"An error occurred while invoking the listener for event '{scheduler_event}': {str(e)}"
-                    self.__logger.error(error_msg)
-                    raise CLIOrionisRuntimeError(error_msg) from e
+                    self.__app.invoke(listener, event_data, self)
+                except BaseException as e:
+                    self.__raiseException(e)
 
     def __taskCallableListener(
         self,
@@ -558,9 +520,7 @@ class Schedule(ISchedule):
 
         # Validate that the provided event is an instance of ListeningEvent
         if not isinstance(listening_vent, ListeningEvent):
-            error_msg = "The event must be an instance of ListeningEvent."
-            self.__logger.error(error_msg)
-            raise CLIOrionisValueError(error_msg)
+            self.__raiseException(CLIOrionisValueError("The event must be an instance of ListeningEvent."))
 
         # Validate that event_data is not None and has a id attribute
         if not isinstance(event_data, EventJob) or not hasattr(event_data, 'id') or not event_data.id:
@@ -578,69 +538,25 @@ class Schedule(ISchedule):
             # Check if the listener is an instance of IScheduleEventListener
             if issubclass(listener, IScheduleEventListener):
 
-                # Initialize the listener if it's a class
-                if isinstance(listener, type):
-                    listener = listener()
+                try:
 
-                # Check if the listener has a method corresponding to the event type
-                if hasattr(listener, scheduler_event) and callable(getattr(listener, scheduler_event)):
+                    # Initialize the listener if it's a class
+                    if isinstance(listener, type):
+                        listener = self.__app.make(listener)
 
-                    # Retrieve the method from the listener
-                    listener_method = getattr(listener, scheduler_event)
+                    # Check if the listener has a method corresponding to the event type
+                    if hasattr(listener, scheduler_event) and callable(getattr(listener, scheduler_event)):
+                        self.__app.call(listener, scheduler_event, event_data, self)
 
-                    try:
+                except BaseException as e:
 
-                        # If the listener_method is a coroutine, handle it properly
-                        if asyncio.iscoroutinefunction(listener_method):
-
-                            try:
-
-                                # Try to get the current running event loop
-                                loop = asyncio.get_running_loop()
-
-                                # Schedule the coroutine as a task in the current loop
-                                loop.create_task(listener_method(event_data, self))
-
-                            except RuntimeError:
-
-                                # No running event loop, create a new one
-                                try:
-
-                                    # Create and run the coroutine in a new event loop
-                                    asyncio.run(listener_method(event_data, self))
-
-                                except Exception as e:
-
-                                    # Handle exceptions during coroutine execution
-                                    error_msg = f"Failed to run async listener_method for '{scheduler_event}': {str(e)}"
-                                    self.__logger.error(error_msg)
-                                    raise CLIOrionisRuntimeError(error_msg) from e
-
-                        else:
-
-                            # Call the regular listener_method function directly
-                            listener_method(event_data, self)
-
-                    except Exception as e:
-
-                        # Re-raise CLIOrionisRuntimeError exceptions
-                        if isinstance(e, CLIOrionisRuntimeError):
-                            raise e
-
-                        # Construct and log error message
-                        error_msg = f"An error occurred while invoking the listener_method for event '{scheduler_event}': {str(e)}"
-                        self.__logger.error(error_msg)
-                        raise CLIOrionisRuntimeError(error_msg) from e
-
-                else:
-
-                    # Log a warning if the listener does not have the required method
-                    self.__logger.warning(f"The listener for job ID '{event_data.id}' does not have a method for event '{scheduler_event}'.")
+                    # If an error occurs while invoking the listener, raise an exception
+                    self.__raiseException(e)
 
             else:
 
-                # Log a warning if the listener is not an instance of IScheduleEventListener
-                self.__logger.warning(f"The listener for job ID '{event_data.id}' is not an instance of IScheduleEventListener.")
+                # If the listener is not a subclass of IScheduleEventListener, raise an exception
+                self.__raiseException(CLIOrionisValueError(f"The listener for job ID '{event_data.id}' must be a subclass of IScheduleEventListener."))
 
     def __startedListener(
         self,
@@ -768,7 +684,7 @@ class Schedule(ISchedule):
             and listener invocation for the job error event.
         """
         # Log an error message indicating that the job raised an exception
-        self.__logger.error(f"Task {event.job_id} raised an exception: {event.exception}")
+        self.__logger.error(f"Task '{event.job_id}' raised an exception: {event.exception}")
 
         # If a listener is registered for this job ID, invoke the listener with the event details
         job_event_data = self.__getTaskFromSchedulerById(event.job_id)
@@ -788,10 +704,7 @@ class Schedule(ISchedule):
         self.__globalCallableListener(event_data, ListeningEvent.SCHEDULER_ERROR)
 
         # Catch any exceptions that occur during command handling
-        self.__catch.exception(self, CLIRequest(
-            command=job_event_data.id,
-            args=list(job_event_data.args) or []
-        ), event.exception)
+        self.__raiseException(event.exception)
 
     def __submittedListener(
         self,
@@ -819,7 +732,7 @@ class Schedule(ISchedule):
         """
 
         # Log an informational message indicating that the job has been submitted
-        self.__logger.info(f"Task {event.job_id} submitted to executor.")
+        self.__logger.info(f"Task '{event.job_id}' submitted to executor.")
 
         # Create entity for job submitted event
         data_event = self.__getTaskFromSchedulerById(event.job_id, event.code)
@@ -854,7 +767,7 @@ class Schedule(ISchedule):
         """
 
         # Log an informational message indicating that the job has been executed
-        self.__logger.info(f"Task {event.job_id} executed.")
+        self.__logger.info(f"Task '{event.job_id}' executed.")
 
         # Create entity for job executed event
         data_event = self.__getTaskFromSchedulerById(event.job_id, event.code)
@@ -889,7 +802,7 @@ class Schedule(ISchedule):
         """
 
         # Log a warning indicating that the job was missed
-        self.__logger.warning(f"Task {event.job_id} was missed. It was scheduled to run at {event.scheduled_run_time}.")
+        self.__logger.warning(f"Task '{event.job_id}' was missed. It was scheduled to run at {event.scheduled_run_time}.")
 
         # Create entity for job missed event
         data_event = self.__getTaskFromSchedulerById(event.job_id, event.code)
@@ -924,7 +837,7 @@ class Schedule(ISchedule):
         """
 
         # Log an error message indicating that the job exceeded maximum instances
-        self.__logger.error(f"Task {event.job_id} exceeded maximum instances")
+        self.__logger.error(f"Task '{event.job_id}' exceeded maximum instances")
 
         # Create entity for job max instances event
         data_event = self.__getTaskFromSchedulerById(event.job_id, event.code)
@@ -958,7 +871,7 @@ class Schedule(ISchedule):
         """
 
         # Log the removal of the job
-        self.__logger.info(f"Task {event.job_id} has been removed.")
+        self.__logger.info(f"Task '{event.job_id}' has been removed.")
 
         # Create entity for job removed event
         data_event = self.__getTaskFromSchedulerById(event.job_id, event.code)
@@ -990,7 +903,7 @@ class Schedule(ISchedule):
 
                 try:
                     # Convert the event to its entity representation
-                    entity = event.toEntity()
+                    entity: EventEntity = event.toEntity()
 
                     # Add the job to the internal jobs list
                     self.__jobs.append(entity)
@@ -1005,7 +918,9 @@ class Schedule(ISchedule):
                         trigger=entity.trigger,
                         id=signature,
                         name=signature,
-                        replace_existing=True
+                        replace_existing=True,
+                        max_instances=entity.max_instances,
+                        misfire_grace_time=entity.misfire_grace_time
                     )
 
                     # If a listener is associated with the event, register it
@@ -1026,6 +941,48 @@ class Schedule(ISchedule):
                     # Raise a runtime error if loading the scheduled event fails
                     raise CLIOrionisRuntimeError(error_msg)
 
+    def __raiseException(
+        self,
+        exception: BaseException
+    ) -> None:
+        """
+        Handle and propagate exceptions through the application's error handling system.
+
+        This private method serves as a centralized exception handler for the scheduler,
+        delegating exception processing to the application's error catching mechanism.
+        It ensures that all exceptions occurring within the scheduler context are
+        properly handled according to the application's error handling policies.
+
+        The method acts as a bridge between the scheduler's internal operations and
+        the application's global exception handling system, providing consistent
+        error handling behavior across the entire application.
+
+        Parameters
+        ----------
+        exception : BaseException
+            The exception instance that was raised during command execution. This can be
+            any type of exception that inherits from BaseException, including system
+            exceptions, custom application exceptions, and runtime errors.
+
+        Returns
+        -------
+        None
+            This method does not return any value. It delegates exception handling
+            to the application's error catching mechanism and may re-raise the
+            exception depending on the configured error handling behavior.
+
+        Notes
+        -----
+        This method is intended for internal use within the scheduler and should not
+        be called directly by external code. The error catching mechanism may perform
+        various actions such as logging, reporting, or re-raising the exception based
+        on the application's configuration.
+        """
+
+        # Delegate exception handling to the application's error catching mechanism
+        # This ensures consistent error handling across the entire application
+        self.__catch.exception(self, CLIRequest(command="schedule:work", args={}), exception)
+
     def setListener(
         self,
         event: Union[str, ListeningEvent],
@@ -1056,7 +1013,7 @@ class Schedule(ISchedule):
 
         Raises
         ------
-        ValueError
+        CLIOrionisValueError
             If the event name is not a non-empty string or if the listener is not callable
             or an instance of IScheduleEventListener.
         """
@@ -1067,11 +1024,11 @@ class Schedule(ISchedule):
 
         # Validate that the event name is a non-empty string
         if not isinstance(event, str) or not event.strip():
-            raise ValueError("Event name must be a non-empty string.")
+            raise CLIOrionisValueError("Event name must be a non-empty string.")
 
         # Validate that the listener is either callable or an instance of IScheduleEventListener
         if not callable(listener) and not isinstance(listener, IScheduleEventListener):
-            raise ValueError("Listener must be a callable function or an instance of IScheduleEventListener.")
+            raise CLIOrionisValueError("Listener must be a callable function or an instance of IScheduleEventListener.")
 
         # Register the listener for the specified event in the internal listeners dictionary
         self.__listeners[event] = listener
@@ -1081,53 +1038,94 @@ class Schedule(ISchedule):
         func: Callable[..., Awaitable[Any]]
     ) -> Callable[..., Any]:
         """
-        Wrap an asynchronous function to be called in a synchronous context.
+        Wrap an asynchronous function to be executed in a synchronous context.
 
-        This method takes an asynchronous function (a coroutine) and returns a synchronous
-        wrapper function that can be called in a non-async context. The wrapper function
-        ensures that the asynchronous function is executed within the appropriate event loop.
+        This method creates a synchronous wrapper around an asynchronous function (coroutine)
+        that enables its execution within non-async contexts. The wrapper leverages the
+        Coroutine utility class to handle the complexities of asyncio event loop management
+        and provides proper error handling with detailed logging and custom exception
+        propagation.
+
+        The wrapper is particularly useful when integrating asynchronous functions with
+        synchronous APIs or frameworks that do not natively support async operations,
+        such as the APScheduler job execution environment.
 
         Parameters
         ----------
         func : Callable[..., Awaitable[Any]]
-            The asynchronous function (coroutine) to be wrapped. This function should be
-            defined using the `async def` syntax and return an awaitable object.
+            The asynchronous function (coroutine) to be wrapped. This function must be
+            defined using the `async def` syntax and return an awaitable object. The
+            function can accept any number of positional and keyword arguments.
 
         Returns
         -------
         Callable[..., Any]
-            A synchronous wrapper function that can be called in a non-async context.
-            When invoked, this wrapper will execute the original asynchronous function
-            within the appropriate event loop.
+            A synchronous wrapper function that executes the original asynchronous
+            function and returns its result. The wrapper function accepts the same
+            arguments as the original async function and forwards them appropriately.
+            The return type depends on what the wrapped asynchronous function returns.
 
         Raises
         ------
         CLIOrionisRuntimeError
-            If the provided `func` is not an asynchronous function or execution fails.
+            If the asynchronous function execution fails or if the provided `func`
+            parameter is not a valid asynchronous function. The original exception
+            is wrapped to provide additional context for debugging.
+
+        Notes
+        -----
+        This method relies on the Coroutine utility class from the orionis.services.asynchrony
+        module to handle the execution of the wrapped asynchronous function. The wrapper
+        uses the instance logger for comprehensive error reporting and debugging information.
         """
 
         def sync_wrapper(*args, **kwargs) -> Any:
+            """
+            Synchronous wrapper function that executes asynchronous functions in a thread-safe manner.
 
+            This wrapper provides a uniform interface for executing asynchronous functions within
+            synchronous contexts by leveraging the Coroutine utility class. It handles the complexity
+            of managing async/await patterns and provides proper error handling with detailed logging
+            and custom exception propagation.
+
+            The wrapper is particularly useful when integrating asynchronous functions with
+            synchronous APIs or frameworks that do not natively support async operations.
+
+            Parameters
+            ----------
+            *args : tuple
+            Variable length argument list to pass to the wrapped asynchronous function.
+            These arguments are forwarded directly to the original function.
+            **kwargs : dict
+            Arbitrary keyword arguments to pass to the wrapped asynchronous function.
+            These keyword arguments are forwarded directly to the original function.
+
+            Returns
+            -------
+            Any
+            The return value from the executed asynchronous function. The type depends
+            on what the wrapped function returns and can be any Python object.
+
+            Raises
+            ------
+            CLIOrionisRuntimeError
+            When the asynchronous function execution fails, wrapping the original
+            exception with additional context and error details for better debugging.
+
+            Notes
+            -----
+            This function relies on the Coroutine utility class to handle the execution
+            of the wrapped asynchronous function and uses the instance logger for comprehensive
+            error reporting and debugging information.
+            """
+
+            # Execute the asynchronous function using the container's invoke method
             try:
+                self.__app.invoke(func, *args, **kwargs)
 
-                # Try to get the current event loop
-                try:
-
-                    # If we're already in an event loop, create a task
-                    loop = asyncio.get_running_loop()
-                    task = loop.create_task(func(*args, **kwargs))
-                    return task
-
-                except RuntimeError:
-
-                    # No running loop, so we can run the coroutine directly
-                    return asyncio.run(func(*args, **kwargs))
-
+            # If an error occurs during execution, raise a custom exception
             except Exception as e:
-
-                # Log the error and re-raise
-                self.__logger.error(f"Error executing async function: {str(e)}")
-                raise CLIOrionisRuntimeError(f"Failed to execute async function: {str(e)}") from e
+                self.__raiseException(e)
 
         # Return the synchronous wrapper function
         return sync_wrapper
@@ -1165,7 +1163,7 @@ class Schedule(ISchedule):
 
         # Validate that the 'at' parameter is a datetime object
         if not isinstance(at, datetime):
-            raise ValueError("The 'at' parameter must be a datetime object.")
+            CLIOrionisValueError("The 'at' parameter must be a datetime object.")
 
         # Define an async function to pause the scheduler
         async def schedule_pause():
@@ -1212,8 +1210,8 @@ class Schedule(ISchedule):
 
                         except Exception as e:
 
-                            # Log a warning if pausing a job fails, but continue with others
-                            self.__logger.warning(f"Failed to pause job '{job.id}': {str(e)}")
+                            # If an error occurs while pausing the job, raise an exception
+                            self.__raiseException(e)
 
                 # Execute the global callable listener after all jobs are paused
                 self.__globalCallableListener(SchedulerPaused(
@@ -1231,7 +1229,7 @@ class Schedule(ISchedule):
                 self.__scheduler.remove_job("scheduler_pause_at")
 
             # If the job doesn't exist, it's fine to proceed
-            except:
+            finally:
                 pass
 
             # Add a job to the scheduler to pause it at the specified datetime
@@ -1284,7 +1282,7 @@ class Schedule(ISchedule):
 
         # Validate that the 'at' parameter is a datetime object
         if not isinstance(at, datetime):
-            raise ValueError("The 'at' parameter must be a datetime object.")
+            raise CLIOrionisValueError("The 'at' parameter must be a datetime object.")
 
         # Define an async function to resume the scheduler
         async def schedule_resume():
@@ -1314,8 +1312,8 @@ class Schedule(ISchedule):
 
                         except Exception as e:
 
-                            # Log a warning if resuming a job fails, but continue with others
-                            self.__logger.warning(f"Failed to resume job '{job_id}': {str(e)}")
+                            # If an error occurs while resuming the job, raise an exception
+                            self.__raiseException(e)
 
                     # Clear the set after resuming all jobs
                     self.__pausedByPauseEverything.clear()
@@ -1342,7 +1340,7 @@ class Schedule(ISchedule):
                 self.__scheduler.remove_job("scheduler_resume_at")
 
             # If the job doesn't exist, it's fine to proceed
-            except:
+            finally:
                 pass
 
             # Add a job to the scheduler to resume it at the specified datetime
@@ -1391,7 +1389,7 @@ class Schedule(ISchedule):
 
         Raises
         ------
-        ValueError
+        CLIOrionisValueError
             If the 'at' parameter is not a valid datetime object or 'wait' is not boolean,
             or if the scheduled time is not in the future.
         CLIOrionisRuntimeError
@@ -1400,11 +1398,11 @@ class Schedule(ISchedule):
 
         # Validate that the 'at' parameter is a datetime object
         if not isinstance(at, datetime):
-            raise ValueError("The 'at' parameter must be a datetime object.")
+            raise CLIOrionisValueError("The 'at' parameter must be a datetime object.")
 
         # Validate that the 'wait' parameter is a boolean
         if not isinstance(wait, bool):
-            raise ValueError("The 'wait' parameter must be a boolean value.")
+            raise CLIOrionisValueError("The 'wait' parameter must be a boolean value.")
 
         # Define an async function to shut down the scheduler
         async def schedule_shutdown():
@@ -1421,8 +1419,7 @@ class Schedule(ISchedule):
                 except Exception as e:
 
                     # Log any errors that occur during shutdown
-                    error_msg = f"Error during scheduled shutdown: {str(e)}"
-                    self.__logger.error(error_msg)
+                    self.__logger.error(f"Error during scheduled shutdown: {str(e)}")
 
                     # Force stop if graceful shutdown fails
                     self.forceStop()
@@ -1434,7 +1431,7 @@ class Schedule(ISchedule):
                 self.__scheduler.remove_job("scheduler_shutdown_at")
 
             # If the job doesn't exist, it's fine to proceed
-            except:
+            finally:
                 pass
 
             # Add a job to the scheduler to shut it down at the specified datetime
@@ -1477,7 +1474,7 @@ class Schedule(ISchedule):
         try:
 
             # Ensure the method is called within an asyncio event loop
-            loop = asyncio.get_running_loop()
+            asyncio.get_running_loop()
 
             # Create an asyncio event to manage clean shutdowns
             self._stop_event = asyncio.Event()
@@ -1556,7 +1553,7 @@ class Schedule(ISchedule):
 
         # Validate the wait parameter
         if not isinstance(wait, bool):
-            raise ValueError("The 'wait' parameter must be a boolean value.")
+            self.__raiseException(CLIOrionisValueError("The 'wait' parameter must be a boolean value."))
 
         # If the scheduler is not running, there's nothing to shut down
         if not self.isRunning():
@@ -1584,9 +1581,9 @@ class Schedule(ISchedule):
         except Exception as e:
 
             # Handle exceptions that may occur during shutdown
-            raise CLIOrionisRuntimeError(f"Failed to shut down the scheduler: {str(e)}") from e
+            self.__raiseException(CLIOrionisRuntimeError(f"Failed to shut down the scheduler: {str(e)}"))
 
-    def pause(self, signature: str) -> bool:
+    def pauseTask(self, signature: str) -> bool:
         """
         Pause a scheduled job in the AsyncIO scheduler.
 
@@ -1614,7 +1611,7 @@ class Schedule(ISchedule):
 
         # Validate that the signature is a non-empty string
         if not isinstance(signature, str) or not signature.strip():
-            raise CLIOrionisValueError("Signature must be a non-empty string.")
+            self.__raiseException(CLIOrionisValueError("Signature must be a non-empty string."))
 
         try:
 
@@ -1632,7 +1629,7 @@ class Schedule(ISchedule):
             # Return False if the job could not be paused (e.g., it does not exist)
             return False
 
-    def resume(self, signature: str) -> bool:
+    def resumeTask(self, signature: str) -> bool:
         """
         Resume a paused job in the AsyncIO scheduler.
 
@@ -1660,7 +1657,7 @@ class Schedule(ISchedule):
 
         # Validate that the signature is a non-empty string
         if not isinstance(signature, str) or not signature.strip():
-            raise CLIOrionisValueError("Signature must be a non-empty string.")
+            self.__raiseException(CLIOrionisValueError("Signature must be a non-empty string."))
 
         try:
             # Attempt to resume the job with the given signature
@@ -1677,7 +1674,7 @@ class Schedule(ISchedule):
             # Return False if the job could not be resumed (e.g., it does not exist)
             return False
 
-    def remove(self, signature: str) -> bool:
+    def removeTask(self, signature: str) -> bool:
         """
         Remove a scheduled job from the AsyncIO scheduler.
 
@@ -1706,7 +1703,7 @@ class Schedule(ISchedule):
 
         # Validate that the signature is a non-empty string
         if not isinstance(signature, str) or not signature.strip():
-            raise CLIOrionisValueError("Signature must be a non-empty string.")
+            self.__raiseException(CLIOrionisValueError("Signature must be a non-empty string."))
 
         try:
 
@@ -1817,7 +1814,8 @@ class Schedule(ISchedule):
             # Return True to indicate the pause job was successfully cancelled
             return True
 
-        except:
+        finally:
+
             # Return False if the pause job does not exist or an error occurred
             return False
 
@@ -1855,7 +1853,7 @@ class Schedule(ISchedule):
             # Return True to indicate the resume job was successfully cancelled
             return True
 
-        except:
+        finally:
 
             # Return False if the resume job does not exist or an error occurred
             return False
@@ -1894,7 +1892,7 @@ class Schedule(ISchedule):
             # Return True to indicate the shutdown job was successfully cancelled
             return True
 
-        except:
+        finally:
 
             # Return False if the shutdown job does not exist or an error occurred
             return False
